Model Results
=============
All model return the same object, a results class (:class:`ARCHModelResult`).
When using the ``fix`` method, a (:class:`ARCHModelFixedResult`) is produced
that lacks some properties of a (:class:`ARCHModelResult`) that are not
relevant when parameters are not estimated.


.. module:: arch.univariate.base
   :noindex:

.. currentmodule:: arch.univariate.base

.. autosummary::
   :toctree: generated/

   ARCHModelResult
   ARCHModelFixedResult
